@@ -12,8 +12,8 @@ echo "Updating bash codes..."
 
 esc_MAINPATH=${ROTT_ETCDIR//\//\\/}
 esc_STATPATH=${ROTT_STATPATH//\//\\/}
-sed -e 's/^MAINPATH=.*/MAINPATH=\"$esc_MAINPATH\"/' \
-    -e 's/^STATPATH=.*/STATPATH=\"$esc_STATPATH\"/' rottlog >newrottlog
+sed -e s/^MAINPATH=.*/MAINPATH=\"$esc_MAINPATH\"/ \
+    -e s/^STATPATH=.*/STATPATH=\"$esc_STATPATH\"/ rottlog >newrottlog
 if [ ! -s newrottlog ]; then
   echo "Error using sed to modify rottlog!!"
   echo "Please send to stefko5@inwind.it an e-mail with as much as possible"
@@ -23,7 +23,7 @@ if [ ! -s newrottlog ]; then
 else
   mv newrottlog rottlog
 fi
-sed -e 's/^MAINPATH=.*/MAINPATH=\"$esc_MAINPATH\"/' virottrc >newvirottrc
+sed -e s/^MAINPATH=.*/MAINPATH=\"$esc_MAINPATH\"/ virottrc >newvirottrc
 if [ ! -s newvirottrc ]; then
   echo "Error using sed to modify virottrc!!"
   echo "Please send to stefko5@inwind.it an e-mail with as much as possible"
